@@ -17,7 +17,7 @@ class MarkdownTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
 
     void testFancyPantsEnabled();
