@@ -19,7 +19,7 @@ EpubDocument::EpubDocument(const QString &fileName, const QFont &font)
     , mFont(font)
 {
 #ifdef Q_OS_WIN
-    mEpub = epub_open(fileName.toUtf8(), 2);
+    mEpub = epub_open(qUtf8Printable(fileName), 2);
 #else
     mEpub = epub_open(qPrintable(fileName), 2);
 #endif
@@ -49,7 +49,7 @@ struct epub *EpubDocument::getEpub()
 void EpubDocument::setCurrentSubDocument(const QString &doc)
 {
     mCurrentSubDocument.clear();
-    int index = doc.indexOf('/');
+    int index = doc.indexOf(QLatin1Char('/'));
     if (index > 0) {
         mCurrentSubDocument = QUrl::fromLocalFile(doc.left(index + 1));
     }
